@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1997, 98, 99 Matthew P. Hodges
+Copyright (C) 1998, 1999, 2000, 2001, 2002, 2004, 2005 Matthew P. Hodges
 This file is part of XMakemol.
 
 XMakemol is free software; you can redistribute it and/or modify
@@ -60,6 +60,7 @@ char * gnu_basename (char *);
 #include "bbox.h" /* wjq */
 
 void echo_to_message_area(char *);
+void place_dialog_cb (Widget, XtPointer, XtPointer);
 
 static int anim_file_type;
 static int stop_anim;
@@ -201,6 +202,7 @@ animate(Widget parent)
 
   }
   
+  XtAddCallback (anim_dialog, XmNmapCallback, place_dialog_cb, NULL);
   XtManageChild(anim_dialog);
 
 }
