@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1997, 98, 99, 2000 Matthew P. Hodges
+Copyright (C) 1998, 1999, 2000, 2001, 2002, 2005 Matthew P. Hodges
 This file is part of XMakemol.
 
 XMakemol is free software; you can redistribute it and/or modify
@@ -41,6 +41,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "globals.h"
 
 void echo_to_message_area(char *);
+void place_dialog_cb (Widget, XtPointer, XtPointer);
 
 enum perspective_types {PERSPECTIVE_ALL,
                         PERSPECTIVE_CURRENT};
@@ -101,6 +102,7 @@ measure(Widget parent)
   if(!meas_dialog){
     XtSetArg (args[n],XmNdialogTitle, label); n++;
     XtSetArg (args[n],XmNautoUnmanage, False); n++;
+    XtSetArg (args[n],XmNdefaultPosition, False); n++;
 
     meas_dialog=(Widget)XmCreateMessageDialog(parent, "lengths", args, n);
 
@@ -285,6 +287,8 @@ measure(Widget parent)
       update_lengths_dialog(True);
   }
 
+  XtAddCallback (meas_dialog, XmNmapCallback, place_dialog_cb, NULL);
+
   XtManageChild(meas_dialog);
   XtPopup(XtParent(meas_dialog), XtGrabNone);
 
@@ -564,6 +568,7 @@ make_pers_dlg(Widget parent)
 
   }
   
+  XtAddCallback (pers_dialog, XmNmapCallback, place_dialog_cb, NULL);
   XtManageChild(pers_dialog);
 
 }
