@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1998, 1999, 2000, 2001, 2002, 2004, 2005 Matthew P. Hodges
+Copyright (C) 1998, 1999, 2000, 2001, 2002, 2004, 2005, 2006 Matthew P. Hodges
 This file is part of XMakemol.
 
 XMakemol is free software; you can redistribute it and/or modify
@@ -32,11 +32,12 @@ char * gnu_basename (char *);
 
 #include <Xm/FileSB.h>
 #include <Xm/Label.h>
+#include <Xm/MessageB.h>
 #include <Xm/PushB.h>
 #include <Xm/RowColumn.h>
 #include <Xm/Scale.h>
 #include <Xm/ScrollBar.h>
-#include <Xm/SelectioB.h>
+#include <Xm/TextF.h>
 #include <Xm/ToggleBG.h>
 
 #ifdef XPM
@@ -95,7 +96,7 @@ make_frame_dlg(Widget parent)
 #endif
 
   Widget rc_ver,rc_hor,start_b,next_b,prev_b,bounce_b,rewind_b;
-  Widget centre_b;
+  Widget centre_b, child;
 
 #ifdef HAVE_USLEEP
   int s, t, nkids;
@@ -105,22 +106,18 @@ make_frame_dlg(Widget parent)
   Widget *kids;
 #endif
 
-  XmString label=XmStringCreateLocalized("Select frame");
+  XmString label = "";
 
-  if(!frames_dialog){
-    XmString ok_str;
-    XtSetArg (args[n],XmNselectionLabelString, label); n++;
-    XtSetArg (args[n],XmNautoUnmanage, False); n++;
-    ok_str=XmStringCreateLocalized("Select");
-    XtSetArg (args[n],XmNokLabelString, ok_str); n++;
+  if (! frames_dialog) {
 
-    frames_dialog=(Widget)XmCreatePromptDialog(parent, "frames", args, n);
+    label = XmStringCreateLocalized ("Frames");   
 
-    XmStringFree(ok_str);
+    XtSetArg (args[n], XmNautoUnmanage, False); n++;
+    XtSetArg (args[n], XmNdialogTitle, label); n++;
+
+    frames_dialog = (Widget)
+      XmCreateMessageDialog (parent, "frames", args, n);
 
-    label=XmStringCreateLocalized ("Frames");   
-    XtVaSetValues(frames_dialog, XmNdialogTitle, label, NULL);
- 
     rc_ver = XtVaCreateManagedWidget
       ("rc_ver",xmRowColumnWidgetClass,frames_dialog,
        NULL);
@@ -129,6 +126,7 @@ make_frame_dlg(Widget parent)
       ("Comment",
        xmLabelWidgetClass, rc_ver,
        XmNlabelString, label,
+       XmNwidth, 400,
        NULL);
 
     update_frame_label();
@@ -214,10 +212,8 @@ make_frame_dlg(Widget parent)
     XtAddCallback(speed_scale_w, XmNvalueChangedCallback,frame_speed_cb,NULL); 
     XtAddCallback(speed_scale_w, XmNdragCallback, frame_speed_cb, NULL);
 
-    XmStringFree(label);
 #endif
 
-    XtAddCallback(frames_dialog, XmNokCallback, frame_no_cb,NULL);
     XtAddCallback(frames_dialog, XmNcancelCallback,
                   frame_dlg_cancel_cb, NULL);
 
@@ -230,18 +226,28 @@ make_frame_dlg(Widget parent)
     XtAddCallback
       (centre_b,XmNvalueChangedCallback,centre_b_cb,NULL);
     
-    /* No help available ... */
+    XtVaCreateManagedWidget
+      ("Select frame:", xmLabelWidgetClass, rc_ver,
+         XmNalignment, XmALIGNMENT_BEGINNING,
+         NULL);
 
-    XtUnmanageChild
-      (XmSelectionBoxGetChild(frames_dialog,XmDIALOG_HELP_BUTTON));
+    child = XtVaCreateManagedWidget
+      ("select_frame", xmTextFieldWidgetClass, rc_ver, NULL);
+
+    XtVaSetValues (child, XmNvalue, "1", NULL);
+
+    XtAddCallback(frames_dialog, XmNokCallback, frame_no_cb, child);
+
+    XtUnmanageChild (XmMessageBoxGetChild
+                     (frames_dialog, XmDIALOG_HELP_BUTTON));
     
   }
 
   XtAddCallback (frames_dialog, XmNmapCallback, place_dialog_cb, NULL);
 
   XtManageChild(frames_dialog);
-  XtPopup(XtParent(frames_dialog), XtGrabNone);
 
+  XmStringFree (label);
 }
 
 
@@ -256,20 +262,23 @@ frame_dlg_cancel_cb(Widget widget, XtPointer client_data, XtPointer call_data)
 
 
 void
-frame_no_cb(Widget widget, XtPointer client_data, XtPointer call_data)
+frame_no_cb (Widget widget,
+             XtPointer client_data,
+             XtPointer call_data)
 {
+  void change_frame (int, Boolean, Boolean);
 
-  void change_frame(int,Boolean,Boolean);
-
+  char string[124], *temp_frame_string;
   int temp_frame;
-  char string[100],*line=NULL;
 
-  XmSelectionBoxCallbackStruct *cbs =
-    (XmSelectionBoxCallbackStruct *) call_data;
+  XtVaGetValues (client_data, XmNvalue, &temp_frame_string, NULL);
 
-  XmStringGetLtoR (cbs->value, XmFONTLIST_DEFAULT_TAG, &line);
-
-  sscanf(line,"%d",&temp_frame);
+  if ((strlen (temp_frame_string) == 0) ||
+      (sscanf (temp_frame_string, "%ld", &temp_frame) <= 0))
+    {
+      echo_to_message_area ("Cannot parse string!");
+      return;
+    }
   
   temp_frame--; /* Frames from 0 to no_frames -1 */
 
